get_optimized_kpoints_transformed — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# get_optimized_kpoints_transformed

KPath.get_optimized_kpoints_transformed(transformation_matrix, same_grid_size=False)

  A method to get the optimized kpoints after a transformation

  Parameters:

    - transformation_matrix (np.ndarray) – The transformmation matrix.

    - same_grid_size (bool) – Boolean to determine if the grid should retain the same size

  Returns:

    pyprocar.core.KPath – The transformed KPath